==> huaweicloudsdkbss-3.1.82-py2.py3-none-any.whl: huaweicloudsdkbss/v2/model/claim_enterprise_multi_account_coupon_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ClaimEnterpriseMultiAccountCouponResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'sub_coupon_id': 'str'
    }

    attribute_map = {
        'sub_coupon_id': 'sub_coupon_id'
    }

    def __init__(self, sub_coupon_id=None):
        """ClaimEnterpriseMultiAccountCouponResponse

        The model defined in huaweicloud sdk

        :param sub_coupon_id: |参数名称：实际回收金额。| |参数的约束及描述：成功时返回|
        :type sub_coupon_id: str
        """
        
        super(ClaimEnterpriseMultiAccountCouponResponse, self).__init__()

        self._sub_coupon_id = None
        self.discriminator = None

        if sub_coupon_id is not None:
            self.sub_coupon_id = sub_coupon_id

    @property
    def sub_coupon_id(self):
        """Gets the sub_coupon_id of this ClaimEnterpriseMultiAccountCouponResponse.

        |参数名称：实际回收金额。| |参数的约束及描述：成功时返回|

        :return: The sub_coupon_id of this ClaimEnterpriseMultiAccountCouponResponse.
        :rtype: str
        """
        return self._sub_coupon_id

    @sub_coupon_id.setter
    def sub_coupon_id(self, sub_coupon_id):
        """Sets the sub_coupon_id of this ClaimEnterpriseMultiAccountCouponResponse.

        |参数名称：实际回收金额。| |参数的约束及描述：成功时返回|

        :param sub_coupon_id: The sub_coupon_id of this ClaimEnterpriseMultiAccountCouponResponse.
        :type sub_coupon_id: str
        """
        self._sub_coupon_id = sub_coupon_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClaimEnterpriseMultiAccountCouponResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkbss-3.1.148-py2.py3-none-any.whl: huaweicloudsdkbss/v2/model/claim_enterprise_multi_account_coupon_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ClaimEnterpriseMultiAccountCouponResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'sub_coupon_id': 'str'
    }

    attribute_map = {
        'sub_coupon_id': 'sub_coupon_id'
    }

    def __init__(self, sub_coupon_id=None):
        r"""ClaimEnterpriseMultiAccountCouponResponse

        The model defined in huaweicloud sdk

        :param sub_coupon_id: |参数名称：实际回收金额。| |参数的约束及描述：成功时返回|
        :type sub_coupon_id: str
        """
        
        super(ClaimEnterpriseMultiAccountCouponResponse, self).__init__()

        self._sub_coupon_id = None
        self.discriminator = None

        if sub_coupon_id is not None:
            self.sub_coupon_id = sub_coupon_id

    @property
    def sub_coupon_id(self):
        r"""Gets the sub_coupon_id of this ClaimEnterpriseMultiAccountCouponResponse.

        |参数名称：实际回收金额。| |参数的约束及描述：成功时返回|

        :return: The sub_coupon_id of this ClaimEnterpriseMultiAccountCouponResponse.
        :rtype: str
        """
        return self._sub_coupon_id

    @sub_coupon_id.setter
    def sub_coupon_id(self, sub_coupon_id):
        r"""Sets the sub_coupon_id of this ClaimEnterpriseMultiAccountCouponResponse.

        |参数名称：实际回收金额。| |参数的约束及描述：成功时返回|

        :param sub_coupon_id: The sub_coupon_id of this ClaimEnterpriseMultiAccountCouponResponse.
        :type sub_coupon_id: str
        """
        self._sub_coupon_id = sub_coupon_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClaimEnterpriseMultiAccountCouponResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
